@@ -114,7 +114,7 @@ class GaitFeaturize:
             Returns formatted dataframe
 
         Return Dataframe Columns:
-            timestamp (dtype: DatetimeIndex) : An index of time in seconds
+            t (dtype: DatetimeIndex) : An index of time in seconds
             x  (dtype: float64) : sensor-values in x axis
             y  (dtype: float64) : sensor-values in y axis
             z  (dtype: float64) : sensor-values in z axis
@@ -123,9 +123,9 @@ class GaitFeaturize:
         """
         data = data.dropna(subset=["x", "y", "z"])
         data["AA"] = np.sqrt(data["x"]**2 + data["y"]**2 + data["z"]**2)
-        data["td"] = data["timestamp"] - data["timestamp"].iloc[0]
-        data["timestamp"] = pd.to_datetime(data["td"], unit="s")
-        data = data.set_index("timestamp")
+        data["td"] = data["t"] - data["t"].iloc[0]
+        data["t"] = pd.to_datetime(data["td"], unit="s")
+        data = data.set_index("t")
         # sort index
         data = data.sort_index()
         # remove data duplicates
@@ -144,8 +144,8 @@ class GaitFeaturize:
         try:
             if data.empty:
                 return "ERROR: Filepath has Empty Dataframe"
-            elif not (set(data.columns) >= set(["x", "y", "z", "timestamp"])):
-                return "ERROR: [timestamp, x, y, z] in columns is required"
+            elif not (set(data.columns) >= set(["x", "y", "z", "t"])):
+                return "ERROR: [t, x, y, z] in columns is required"
             else:
                 data = self.format_time_series_data(data)
             return self.resample_signal(data)
